Enum Dtcefd
#[repr(u8)]pub enum Dtcefd {
Enabled = 0,
Disabled = 1,
}Variants
Enabled = 0
Drop frames with errors only in the receive checksum offload engine
Disabled = 1
Do not drop frames that only have errors in the receive checksum offload engine
Implementations